@@ -8,21 +8,10 @@ import celery
 from celery.events import EventReceiver
 from celery.messaging import establish_connection
 from celery.events.state import state
-from celery.events.snapshot import Polaroid
 
 celery = celery.current_app
 
 
-class DumpCam(Polaroid):
-    def __init__(self, state, freq=1.0):
-        Polaroid.__init__(self, state, freq)
-
-    def on_shutter(self, state):
-        if not state.event_count:
-            # No new events since last snapshot.
-            return
-
-
 class EventCollector(threading.Thread):
     def __init__(self):
         threading.Thread.__init__(self)
@@ -36,9 +25,8 @@ class EventCollector(threading.Thread):
             try:
                 with establish_connection() as connection:
                     recv = EventReceiver(
-                            connection, handlers={"*": state.event})
-                    with DumpCam(state, freq=1.0):
-                        recv.capture(limit=None, timeout=None)
+                                connection, handlers={"*": state.event})
+                    recv.capture(limit=None, timeout=None)
             except (KeyboardInterrupt, SystemExit):
                 import thread
                 thread.interrupt_main()
