@@ -8,14 +8,13 @@ from ..models import WorkersModel, WorkerModel
 
 class WorkersView(BaseHandler):
     def get(self):
-        self.render("workers.html",
-                    workers=WorkersModel.get_latest().workers)
+        self.render("workers.html", workers=WorkersModel.get_latest().workers)
 
 
 class WorkerView(BaseHandler):
     def get(self, workername):
         worker = WorkerModel.get_worker(workername)
         if worker is None:
-            raise web.HTTPError(404)
+            raise web.HTTPError(404, "Unknown worker '%s'" % workername)
 
         self.render("worker.html", worker=worker)
